import matplotlib.pyplot as plt
import deepdish as dd
import numpy as np

# Load data

data  = dd.io.load("../../Event_Samples/default/o1o2o3_mass_c_iid_mag_two_comp_iid_tilt_powerlaw_redshift_samples.hdf5")
events = data['names']
idx = events.index("S190521g")

mass_1  = data['original']['mass_1'][idx]
weights = data['original']['weights'][idx]

def weighted_quantile(samples, weights, q):
    #given samples and corresponding weights, find qth quantiles
    sorter = np.argsort(samples)
    weights = weights[sorter]
    samples = samples[sorter]
    
    weights /= np.sum(weights) #normalize

    weighted_q = np.cumsum(weights)

    return np.interp(q, weighted_q, samples)

mass1_1and99_percentile = weighted_quantile(mass_1, weights, [0.01, 0.99])

stat_file = open('GW190521_m1_stats.txt', 'w')

stat_file.write("%"+"1 percentile of population-informed m1 posterior for GW190521"+"\n")
stat_file.write("\\newcommand{\\%s}{\ensuremath{%s}}\n" % ("PrimaryMassMayOnePercentile", int(round(mass1_1and99_percentile[0],2))))
stat_file.write("\n")
stat_file.write("%"+"99 percentile of population-informed m1 posterior for GW190521"+"\n")
stat_file.write("\\newcommand{\\%s}{\ensuremath{%s}}\n" % ("PrimaryMassMayNinetyNinePercentile", int(round(mass1_1and99_percentile[1],2))))
stat_file.write("\n")
